## Introduction

MalSearch is a library that allows to collect malware samples from multiple malware databases using their API's. It relies on:

- [Maldatabase](https://maldatabase.com/api-doc.html)
- [Malpedia](https://malpedia.caad.fkie.fraunhofer.de/usage/api)
- [MalShare](https://malshare.com/doc.php)
- [Malware Bazaar](https://bazaar.abuse.ch/api)
- [Triage](https://tria.ge/docs)
- [VirusShare](https://virusshare.com/apiv2_reference)
- [VirusTotal](https://docs.virustotal.com/reference/overview)


## Setup

This library is available on [PyPi](https://pypi.python.org/pypi/malsearch/) and can be simply installed using Pip:

```sh
pip install malsearch
```

